@@ -22,21 +22,19 @@
 #ifndef SHORTCUT_H
 #define SHORTCUT_H
 
-#include <QtCore/qnamespace.h>
+#include <qnamespace.h>
 
-namespace Konsole
-{
+namespace Konsole {
 /**
  * Platform-specific main shortcut "opcode":
  */
 enum Modifier {
-#ifdef Q_OS_OSX
+#ifdef Q_OS_MACOS
     ACCEL = Qt::META
 #else
     ACCEL = Qt::CTRL
 #endif
 };
-
 }
 
 #endif //SHORTCUT_H
